@@ -42,7 +42,7 @@ class WebApi(threading.Thread):
         "&localtime="+time.strftime("%H:%M:%S",time.localtime(self.timeStamp))+\
         "&readerserial="+SERIAL_NO
         url = baseUrl+service+self.client+keys
-        #print("addtest",url)
+        print("addtest",url)
         payload  = {}
         headers  = {}
         response = requests.request("POST", url, headers=headers, data=payload)
